EmailVerificationService class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
EmailVerificationState> - EmailVerificationService
Constructors
- EmailVerificationService(FirebaseAuth auth)
Properties
- auth → FirebaseAuth
-
final
- error ↔ Exception?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → EmailVerificationState
-
no setter
- user → User
-
no setter
- value ↔ EmailVerificationState
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dismiss(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
reload(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendVerificationEmail(
TargetPlatform platform, ActionCodeSettings? actionCodeSettings) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited